--- misc/tableselect.js.orig	2009-01-23 22:04:20.000000000 +0100
+++ misc/tableselect.js	2009-01-23 22:04:30.000000000 +0100
@@ -36,8 +36,8 @@ Drupal.tableSelect = function() {
     }
   });
 
-  // For each of the checkboxes within the table.
-  checkboxes = $('td input:checkbox', table).click(function(e) {
+  // For each of the enabled checkboxes within the table.
+  checkboxes = $('td input:checkbox:enabled', table).click(function(e) {
     // Either add or remove the selected class based on the state of the check all checkbox.
     $(this).parents('tr:first')[ this.checked ? 'addClass' : 'removeClass' ]('selected');
 
